==> skill-core-15.0.1-sources.jar: com/ptteng/common/skill/model/Task.java <==
package com.ptteng.common.skill.model;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;

import com.ptteng.skill.service.model.UserTaskRelation;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


@Entity
@Table(name = "task")
public class Task implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 3909751420325317632L;


    private Long id;


    private Long oid;


    private Long num;


    private String title;


    private String description;


    private String time;


    private String step;

    private String extend;



    
    

    private Long createBy;


    private Long updateBy;


    private Long updateAt;


    private Long createAt;

    private Integer dailyScore;

    private String judgeRemark;

    private Integer progress = UserTaskRelation.PROGRESS_UNRECEIVE;
    private BigDecimal value;


    
    /**
     * 修真院13期添加 
     * wanghuan
     */
    
    private String taskPassingRate;
    private Integer taskCompleteTotal;
    private Integer taskCompleteTotalOffline;
    private Integer taskCompleteTotalOutline;
    private Integer taskCompleteTotalOnline;
    private Integer taskSubmitTaskTotal;
    private Integer taskSubmitTaskOffline;
    private Integer taskSubmitTaskOutline;
    private Integer taskSubmitTaskOnline;
    private Integer taskReceiveTaskTotal;
    private Integer taskReceiveTaskOffline;
    private Integer taskReceiveTaskOutline;
    private Integer taskReceiveTaskOnline;
    private Integer taskAverageTimeTotal;
    private Integer taskAverageTimeOffline;
    private Integer taskAverageTimeOutline;
    private Integer taskAverageTimeOnline;
    private Integer taskDailyQualityTotal;
    private Integer taskDailyQualityOffline;
    private Integer taskDailyQualityOutline;
    private Integer taskDailyQualityOnline;
    
	@Column(name="task_passing_rate")
    public String getTaskPassingRate() {
		return taskPassingRate;
	}


	public void setTaskPassingRate(String taskPassingRate) {
		this.taskPassingRate = taskPassingRate;
	}

	@Column(name="task_complete_total")
	public Integer getTaskCompleteTotal() {
		return taskCompleteTotal;
	}


	public void setTaskCompleteTotal(Integer taskCompleteTotal) {
		this.taskCompleteTotal = taskCompleteTotal;
	}

	@Column(name="task_complete_total_offline")
	public Integer getTaskCompleteTotalOffline() {
		return taskCompleteTotalOffline;
	}


	public void setTaskCompleteTotalOffline(Integer taskCompleteTotalOffline) {
		this.taskCompleteTotalOffline = taskCompleteTotalOffline;
	}

	@Column(name="task_complete_total_outline")
	public Integer getTaskCompleteTotalOutline() {
		return taskCompleteTotalOutline;
	}


	public void setTaskCompleteTotalOutline(Integer taskCompleteTotalOutline) {
		this.taskCompleteTotalOutline = taskCompleteTotalOutline;
	}

	@Column(name="task_complete_total_online")
	public Integer getTaskCompleteTotalOnline() {
		return taskCompleteTotalOnline;
	}


	public void setTaskCompleteTotalOnline(Integer taskCompleteTotalOnline) {
		this.taskCompleteTotalOnline = taskCompleteTotalOnline;
	}

	@Column(name="task_submit_task_total")
	public Integer getTaskSubmitTaskTotal() {
		return taskSubmitTaskTotal;
	}


	public void setTaskSubmitTaskTotal(Integer taskSubmitTaskTotal) {
		this.taskSubmitTaskTotal = taskSubmitTaskTotal;
	}

	@Column(name="task_submit_task_offline")
	public Integer getTaskSubmitTaskOffline() {
		return taskSubmitTaskOffline;
	}


	public void setTaskSubmitTaskOffline(Integer taskSubmitTaskOffline) {
		this.taskSubmitTaskOffline = taskSubmitTaskOffline;
	}

	@Column(name="task_submit_task_outline")
	public Integer getTaskSubmitTaskOutline() {
		return taskSubmitTaskOutline;
	}


	public void setTaskSubmitTaskOutline(Integer taskSubmitTaskOutline) {
		this.taskSubmitTaskOutline = taskSubmitTaskOutline;
	}

	@Column(name="task_submit_task_online")
	public Integer getTaskSubmitTaskOnline() {
		return taskSubmitTaskOnline;
	}


	public void setTaskSubmitTaskOnline(Integer taskSubmitTaskOnline) {
		this.taskSubmitTaskOnline = taskSubmitTaskOnline;
	}

	@Column(name="task_receive_task_total")
	public Integer getTaskReceiveTaskTotal() {
		return taskReceiveTaskTotal;
	}


	public void setTaskReceiveTaskTotal(Integer taskReceiveTaskTotal) {
		this.taskReceiveTaskTotal = taskReceiveTaskTotal;
	}

	@Column(name="task_receive_task_offline")
	public Integer getTaskReceiveTaskOffline() {
		return taskReceiveTaskOffline;
	}


	public void setTaskReceiveTaskOffline(Integer taskReceiveTaskOffline) {
		this.taskReceiveTaskOffline = taskReceiveTaskOffline;
	}

	@Column(name="task_receive_task_outline")
	public Integer getTaskReceiveTaskOutline() {
		return taskReceiveTaskOutline;
	}


	public void setTaskReceiveTaskOutline(Integer taskReceiveTaskOutline) {
		this.taskReceiveTaskOutline = taskReceiveTaskOutline;
	}

	@Column(name="task_receive_task_online")
	public Integer getTaskReceiveTaskOnline() {
		return taskReceiveTaskOnline;
	}


	public void setTaskReceiveTaskOnline(Integer taskReceiveTaskOnline) {
		this.taskReceiveTaskOnline = taskReceiveTaskOnline;
	}

	@Column(name="task_average_time_total")
	public Integer getTaskAverageTimeTotal() {
		return taskAverageTimeTotal;
	}


	public void setTaskAverageTimeTotal(Integer taskAverageTimeTotal) {
		this.taskAverageTimeTotal = taskAverageTimeTotal;
	}

	@Column(name="task_average_time_offline")
	public Integer getTaskAverageTimeOffline() {
		return taskAverageTimeOffline;
	}


	public void setTaskAverageTimeOffline(Integer taskAverageTimeOffline) {
		this.taskAverageTimeOffline = taskAverageTimeOffline;
	}

	@Column(name="task_average_time_outline")
	public Integer getTaskAverageTimeOutline() {
		return taskAverageTimeOutline;
	}


	public void setTaskAverageTimeOutline(Integer taskAverageTimeOutline) {
		this.taskAverageTimeOutline = taskAverageTimeOutline;
	}

	@Column(name="task_average_time_online")
	public Integer getTaskAverageTimeOnline() {
		return taskAverageTimeOnline;
	}


	public void setTaskAverageTimeOnline(Integer taskAverageTimeOnline) {
		this.taskAverageTimeOnline = taskAverageTimeOnline;
	}

	@Column(name="task_daily_quality_total")
	public Integer getTaskDailyQualityTotal() {
		return taskDailyQualityTotal;
	}


	public void setTaskDailyQualityTotal(Integer taskDailyQualityTotal) {
		this.taskDailyQualityTotal = taskDailyQualityTotal;
	}

	@Column(name="task_daily_quality_offline")
	public Integer getTaskDailyQualityOffline() {
		return taskDailyQualityOffline;
	}


	public void setTaskDailyQualityOffline(Integer taskDailyQualityOffline) {
		this.taskDailyQualityOffline = taskDailyQualityOffline;
	}

	@Column(name="task_daily_quality_outline")
	public Integer getTaskDailyQualityOutline() {
		return taskDailyQualityOutline;
	}


	public void setTaskDailyQualityOutline(Integer taskDailyQualityOutline) {
		this.taskDailyQualityOutline = taskDailyQualityOutline;
	}

	@Column(name="task_daily_quality_online")
	public Integer getTaskDailyQualityOnline() {
		return taskDailyQualityOnline;
	}


	public void setTaskDailyQualityOnline(Integer taskDailyQualityOnline) {
		this.taskDailyQualityOnline = taskDailyQualityOnline;
	}


	@Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id")
    public Long getId() {
        return id;
    }


    public void setId(Long id) {
        this.id = id;
    }


    @Column(name = "value")
    public BigDecimal getValue() {
        return value;
    }

    public void setValue(BigDecimal value) {
        this.value = value;
    }

    @Transient
    public Integer getProgress() {
        return progress;
    }

    public void setProgress(Integer progress) {
        this.progress = progress;
    }

    @Column(name = "oid")
    public Long getOid() {
        return oid;
    }

    public void setOid(Long oid) {
        this.oid = oid;
    }

    @Column(name = "num")
    public Long getNum() {
        return num;
    }

    public void setNum(Long num) {
        this.num = num;
    }

    @Column(name = "title")
    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    @Column(name = "description")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @Column(name = "time")
    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    @Column(name = "step")
    public String getStep() {
        return step;
    }

    public void setStep(String step) {
        this.step = step;
    }
    
    
    

  

	@Column(name = "extend")
	public String getExtend() {
		return extend;
	}


	public void setExtend(String extend) {
		this.extend = extend;
	}
	
	
	
	
	

	

	@Column(name = "create_by")
    public Long getCreateBy() {
        return createBy;
    }


    public void setCreateBy(Long createBy) {
        this.createBy = createBy;
    }

    @Column(name = "update_by")
    public Long getUpdateBy() {
        return updateBy;
    }


    public void setUpdateBy(Long updateBy) {
        this.updateBy = updateBy;
    }

    @Column(name = "update_at")
    public Long getUpdateAt() {
        return updateAt;
    }


    public void setUpdateAt(Long updateAt) {
        this.updateAt = updateAt;
    }

    @Column(name = "create_at")
    public Long getCreateAt() {
        return createAt;
    }


    public void setCreateAt(Long createAt) {
        this.createAt = createAt;
    }

    public String toString() {
        return ToStringBuilder.reflectionToString(this,
                ToStringStyle.MULTI_LINE_STYLE);
    }

	@Transient
	public Integer getDailyScore() {
		return dailyScore;
	}

	public void setDailyScore(Integer dailyScore) {
		this.dailyScore = dailyScore;
	}


	@Transient
	public String getJudgeRemark() {
		return judgeRemark;
	}

	public void setJudgeRemark(String judgeRemark) {
		this.judgeRemark = judgeRemark;
	}



}

==> skill-core-30.0.0-sources.jar: com/ptteng/common/skill/model/Task.java <==
package com.ptteng.common.skill.model;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;

import com.ptteng.skill.service.model.UserTaskRelation;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


@Entity
@Table(name = "task")
public class Task implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 3909751420325317632L;


    private Long id;


    private Long oid;


    private Long num;


    private String title;


    private String description;


    private String time;


    private String step;

    private String extend;



    
    

    private Long createBy;


    private Long updateBy;


    private Long updateAt;


    private Long createAt;

    private Integer dailyScore;

    private String judgeRemark;

    private Integer progress = UserTaskRelation.PROGRESS_UNRECEIVE;
    private BigDecimal value;


    
    /**
     * 修真院13期添加 
     * wanghuan
     */
    
    private String taskPassingRate;
    private Integer taskCompleteTotal;
    private Integer taskCompleteTotalOffline;
    private Integer taskCompleteTotalOutline;
    private Integer taskCompleteTotalOnline;
    private Integer taskSubmitTaskTotal;
    private Integer taskSubmitTaskOffline;
    private Integer taskSubmitTaskOutline;
    private Integer taskSubmitTaskOnline;
    private Integer taskReceiveTaskTotal;
    private Integer taskReceiveTaskOffline;
    private Integer taskReceiveTaskOutline;
    private Integer taskReceiveTaskOnline;
    private Integer taskAverageTimeTotal;
    private Integer taskAverageTimeOffline;
    private Integer taskAverageTimeOutline;
    private Integer taskAverageTimeOnline;
    private Integer taskDailyQualityTotal;
    private Integer taskDailyQualityOffline;
    private Integer taskDailyQualityOutline;
    private Integer taskDailyQualityOnline;
	//19期添加
	private long sid;

	@Column(name="sid")
	public Long getSid() {
		return sid;
	}


	public void setSid(Long sid) {
		this.sid = sid;
	}


	@Column(name="task_passing_rate")
    public String getTaskPassingRate() {
		return taskPassingRate;
	}


	public void setTaskPassingRate(String taskPassingRate) {
		this.taskPassingRate = taskPassingRate;
	}

	@Column(name="task_complete_total")
	public Integer getTaskCompleteTotal() {
		return taskCompleteTotal;
	}


	public void setTaskCompleteTotal(Integer taskCompleteTotal) {
		this.taskCompleteTotal = taskCompleteTotal;
	}

	@Column(name="task_complete_total_offline")
	public Integer getTaskCompleteTotalOffline() {
		return taskCompleteTotalOffline;
	}


	public void setTaskCompleteTotalOffline(Integer taskCompleteTotalOffline) {
		this.taskCompleteTotalOffline = taskCompleteTotalOffline;
	}

	@Column(name="task_complete_total_outline")
	public Integer getTaskCompleteTotalOutline() {
		return taskCompleteTotalOutline;
	}


	public void setTaskCompleteTotalOutline(Integer taskCompleteTotalOutline) {
		this.taskCompleteTotalOutline = taskCompleteTotalOutline;
	}

	@Column(name="task_complete_total_online")
	public Integer getTaskCompleteTotalOnline() {
		return taskCompleteTotalOnline;
	}


	public void setTaskCompleteTotalOnline(Integer taskCompleteTotalOnline) {
		this.taskCompleteTotalOnline = taskCompleteTotalOnline;
	}

	@Column(name="task_submit_task_total")
	public Integer getTaskSubmitTaskTotal() {
		return taskSubmitTaskTotal;
	}


	public void setTaskSubmitTaskTotal(Integer taskSubmitTaskTotal) {
		this.taskSubmitTaskTotal = taskSubmitTaskTotal;
	}

	@Column(name="task_submit_task_offline")
	public Integer getTaskSubmitTaskOffline() {
		return taskSubmitTaskOffline;
	}


	public void setTaskSubmitTaskOffline(Integer taskSubmitTaskOffline) {
		this.taskSubmitTaskOffline = taskSubmitTaskOffline;
	}

	@Column(name="task_submit_task_outline")
	public Integer getTaskSubmitTaskOutline() {
		return taskSubmitTaskOutline;
	}


	public void setTaskSubmitTaskOutline(Integer taskSubmitTaskOutline) {
		this.taskSubmitTaskOutline = taskSubmitTaskOutline;
	}

	@Column(name="task_submit_task_online")
	public Integer getTaskSubmitTaskOnline() {
		return taskSubmitTaskOnline;
	}


	public void setTaskSubmitTaskOnline(Integer taskSubmitTaskOnline) {
		this.taskSubmitTaskOnline = taskSubmitTaskOnline;
	}

	@Column(name="task_receive_task_total")
	public Integer getTaskReceiveTaskTotal() {
		return taskReceiveTaskTotal;
	}


	public void setTaskReceiveTaskTotal(Integer taskReceiveTaskTotal) {
		this.taskReceiveTaskTotal = taskReceiveTaskTotal;
	}

	@Column(name="task_receive_task_offline")
	public Integer getTaskReceiveTaskOffline() {
		return taskReceiveTaskOffline;
	}


	public void setTaskReceiveTaskOffline(Integer taskReceiveTaskOffline) {
		this.taskReceiveTaskOffline = taskReceiveTaskOffline;
	}

	@Column(name="task_receive_task_outline")
	public Integer getTaskReceiveTaskOutline() {
		return taskReceiveTaskOutline;
	}


	public void setTaskReceiveTaskOutline(Integer taskReceiveTaskOutline) {
		this.taskReceiveTaskOutline = taskReceiveTaskOutline;
	}

	@Column(name="task_receive_task_online")
	public Integer getTaskReceiveTaskOnline() {
		return taskReceiveTaskOnline;
	}


	public void setTaskReceiveTaskOnline(Integer taskReceiveTaskOnline) {
		this.taskReceiveTaskOnline = taskReceiveTaskOnline;
	}

	@Column(name="task_average_time_total")
	public Integer getTaskAverageTimeTotal() {
		return taskAverageTimeTotal;
	}


	public void setTaskAverageTimeTotal(Integer taskAverageTimeTotal) {
		this.taskAverageTimeTotal = taskAverageTimeTotal;
	}

	@Column(name="task_average_time_offline")
	public Integer getTaskAverageTimeOffline() {
		return taskAverageTimeOffline;
	}


	public void setTaskAverageTimeOffline(Integer taskAverageTimeOffline) {
		this.taskAverageTimeOffline = taskAverageTimeOffline;
	}

	@Column(name="task_average_time_outline")
	public Integer getTaskAverageTimeOutline() {
		return taskAverageTimeOutline;
	}


	public void setTaskAverageTimeOutline(Integer taskAverageTimeOutline) {
		this.taskAverageTimeOutline = taskAverageTimeOutline;
	}

	@Column(name="task_average_time_online")
	public Integer getTaskAverageTimeOnline() {
		return taskAverageTimeOnline;
	}


	public void setTaskAverageTimeOnline(Integer taskAverageTimeOnline) {
		this.taskAverageTimeOnline = taskAverageTimeOnline;
	}

	@Column(name="task_daily_quality_total")
	public Integer getTaskDailyQualityTotal() {
		return taskDailyQualityTotal;
	}


	public void setTaskDailyQualityTotal(Integer taskDailyQualityTotal) {
		this.taskDailyQualityTotal = taskDailyQualityTotal;
	}

	@Column(name="task_daily_quality_offline")
	public Integer getTaskDailyQualityOffline() {
		return taskDailyQualityOffline;
	}


	public void setTaskDailyQualityOffline(Integer taskDailyQualityOffline) {
		this.taskDailyQualityOffline = taskDailyQualityOffline;
	}

	@Column(name="task_daily_quality_outline")
	public Integer getTaskDailyQualityOutline() {
		return taskDailyQualityOutline;
	}


	public void setTaskDailyQualityOutline(Integer taskDailyQualityOutline) {
		this.taskDailyQualityOutline = taskDailyQualityOutline;
	}

	@Column(name="task_daily_quality_online")
	public Integer getTaskDailyQualityOnline() {
		return taskDailyQualityOnline;
	}


	public void setTaskDailyQualityOnline(Integer taskDailyQualityOnline) {
		this.taskDailyQualityOnline = taskDailyQualityOnline;
	}


	@Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id")
    public Long getId() {
        return id;
    }


    public void setId(Long id) {
        this.id = id;
    }


    @Column(name = "value")
    public BigDecimal getValue() {
        return value;
    }

    public void setValue(BigDecimal value) {
        this.value = value;
    }

    @Transient
    public Integer getProgress() {
        return progress;
    }

    public void setProgress(Integer progress) {
        this.progress = progress;
    }

    @Column(name = "oid")
    public Long getOid() {
        return oid;
    }

    public void setOid(Long oid) {
        this.oid = oid;
    }

    @Column(name = "num")
    public Long getNum() {
        return num;
    }

    public void setNum(Long num) {
        this.num = num;
    }

    @Column(name = "title")
    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    @Column(name = "description")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @Column(name = "time")
    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    @Column(name = "step")
    public String getStep() {
        return step;
    }

    public void setStep(String step) {
        this.step = step;
    }
    
    
    

  

	@Column(name = "extend")
	public String getExtend() {
		return extend;
	}


	public void setExtend(String extend) {
		this.extend = extend;
	}
	
	
	
	
	

	

	@Column(name = "create_by")
    public Long getCreateBy() {
        return createBy;
    }


    public void setCreateBy(Long createBy) {
        this.createBy = createBy;
    }

    @Column(name = "update_by")
    public Long getUpdateBy() {
        return updateBy;
    }


    public void setUpdateBy(Long updateBy) {
        this.updateBy = updateBy;
    }

    @Column(name = "update_at")
    public Long getUpdateAt() {
        return updateAt;
    }


    public void setUpdateAt(Long updateAt) {
        this.updateAt = updateAt;
    }

    @Column(name = "create_at")
    public Long getCreateAt() {
        return createAt;
    }


    public void setCreateAt(Long createAt) {
        this.createAt = createAt;
    }

    public String toString() {
        return ToStringBuilder.reflectionToString(this,
                ToStringStyle.MULTI_LINE_STYLE);
    }

	@Transient
	public Integer getDailyScore() {
		return dailyScore;
	}

	public void setDailyScore(Integer dailyScore) {
		this.dailyScore = dailyScore;
	}


	@Transient
	public String getJudgeRemark() {
		return judgeRemark;
	}

	public void setJudgeRemark(String judgeRemark) {
		this.judgeRemark = judgeRemark;
	}



}
